<?php
/**
 * The main Kirki object
 *
 * @package     Kirki
 * @category    Core
 * @author      Aristeides Stathopoulos
 * @copyright   Copyright (c) 2015, Aristeides Stathopoulos
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       1.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Early exit if the class already exists
if ( class_exists( 'Kirki_Toolkit' ) ) {
	return;
}

final class Kirki_Toolkit {

	/** @var Kirki The only instance of this class */
	public static $instance = null;

	public static $version = '1.0.2';

	public $font_registry = null;
	public $scripts = null;
	public $api = null;
	public $styles = array();

	/**
	 * Access the single instance of this class
	 * @return Kirki
	 */
	public static function get_instance() {
		if ( null == self::$instance ) {
			self::$instance = new Kirki_Toolkit();
		}

		return self::$instance;
	}

	/**
	 * Shortcut method to get the translation strings
	 */
	public static function i18n() {

		$i18n = array(
			'background-color'      => __( 'Background Color', 'tm-lawyers' ),
			'background-image'      => __( 'Background Image', 'tm-lawyers' ),
			'no-repeat'             => __( 'No Repeat', 'tm-lawyers' ),
			'repeat-all'            => __( 'Repeat All', 'tm-lawyers' ),
			'repeat-x'              => __( 'Repeat Horizontally', 'tm-lawyers' ),
			'repeat-y'              => __( 'Repeat Vertically', 'tm-lawyers' ),
			'inherit'               => __( 'Inherit', 'tm-lawyers' ),
			'background-repeat'     => __( 'Background Repeat', 'tm-lawyers' ),
			'cover'                 => __( 'Cover', 'tm-lawyers' ),
			'contain'               => __( 'Contain', 'tm-lawyers' ),
			'background-size'       => __( 'Background Size', 'tm-lawyers' ),
			'fixed'                 => __( 'Fixed', 'tm-lawyers' ),
			'scroll'                => __( 'Scroll', 'tm-lawyers' ),
			'background-attachment' => __( 'Background Attachment', 'tm-lawyers' ),
			'left-top'              => __( 'Left Top', 'tm-lawyers' ),
			'left-center'           => __( 'Left Center', 'tm-lawyers' ),
			'left-bottom'           => __( 'Left Bottom', 'tm-lawyers' ),
			'right-top'             => __( 'Right Top', 'tm-lawyers' ),
			'right-center'          => __( 'Right Center', 'tm-lawyers' ),
			'right-bottom'          => __( 'Right Bottom', 'tm-lawyers' ),
			'center-top'            => __( 'Center Top', 'tm-lawyers' ),
			'center-center'         => __( 'Center Center', 'tm-lawyers' ),
			'center-bottom'         => __( 'Center Bottom', 'tm-lawyers' ),
			'background-position'   => __( 'Background Position', 'tm-lawyers' ),
			'background-opacity'    => __( 'Background Opacity', 'tm-lawyers' ),
			'on'                    => __( 'ON', 'tm-lawyers' ),
			'off'                   => __( 'OFF', 'tm-lawyers' ),
			'all'                   => __( 'All', 'tm-lawyers' ),
			'cyrillic'              => __( 'Cyrillic', 'tm-lawyers' ),
			'cyrillic-ext'          => __( 'Cyrillic Extended', 'tm-lawyers' ),
			'devanagari'            => __( 'Devanagari', 'tm-lawyers' ),
			'greek'                 => __( 'Greek', 'tm-lawyers' ),
			'greek-ext'             => __( 'Greek Extended', 'tm-lawyers' ),
			'khmer'                 => __( 'Khmer', 'tm-lawyers' ),
			'latin'                 => __( 'Latin', 'tm-lawyers' ),
			'latin-ext'             => __( 'Latin Extended', 'tm-lawyers' ),
			'vietnamese'            => __( 'Vietnamese', 'tm-lawyers' ),
			'hebrew'                => __( 'Hebrew', 'tm-lawyers' ),
			'arabic'                => __( 'Arabic', 'tm-lawyers' ),
			'bengali'               => __( 'Bengali', 'tm-lawyers' ),
			'gujarati'              => __( 'Gujarati', 'tm-lawyers' ),
			'tamil'                 => __( 'Tamil', 'tm-lawyers' ),
			'telugu'                => __( 'Telugu', 'tm-lawyers' ),
			'thai'                  => __( 'Thai', 'tm-lawyers' ),
			'serif'                 => _x( 'Serif', 'font style', 'tm-lawyers' ),
			'sans-serif'            => _x( 'Sans Serif', 'font style', 'tm-lawyers' ),
			'monospace'             => _x( 'Monospace', 'font style', 'tm-lawyers' ),
			'font-family'           => __( 'Font Family', 'tm-lawyers' ),
			'font-size'             => __( 'Font Size', 'tm-lawyers' ),
			'font-weight'           => __( 'Font Weight', 'tm-lawyers' ),
			'line-height'           => __( 'Line Height', 'tm-lawyers' ),
			'letter-spacing'        => __( 'Letter Spacing', 'tm-lawyers' ),
			'top'                   => __( 'Top', 'tm-lawyers' ),
			'bottom'                => __( 'Bottom', 'tm-lawyers' ),
			'left'                  => __( 'Left', 'tm-lawyers' ),
			'right'                 => __( 'Right', 'tm-lawyers' ),
		);

		$config = apply_filters( 'kirki/config', array() );

		if ( isset( $config['i18n'] ) ) {
			$i18n = wp_parse_args( $config['i18n'], $i18n );
		}

		return $i18n;

	}

	/**
	 * Shortcut method to get the font registry.
	 */
	public static function fonts() {
		return self::get_instance()->font_registry;
	}

	/**
	 * Constructor is private, should only be called by get_instance()
	 */
	private function __construct() {
	}

	/**
	 * Return true if we are debugging Kirki.
	 */
	public static function kirki_debug() {
		return (bool) ( defined( 'KIRKI_DEBUG' ) && KIRKI_DEBUG );
	}

}
