<?php
/**
 * TM Lawyers functions and definitions
 *
 * @package TM Lawyers
 */

if ( ! function_exists( 'tm_lawyers_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 * ===========================================================================
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function tm_lawyers_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on TM Lawyers, use a find and replace
		 * to change 'tm-lawyers' to the name of your theme in all the template files
		 */
		load_theme_textdomain( 'tm-lawyers', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
		 */
		add_theme_support( 'post-thumbnails' );

		add_image_size( 'tm-lawyers-post-thumb', 848, 450, true );
		add_image_size( 'tm-lawyers-small-thumb', 80, 80, true );
		add_image_size( 'tm-lawyers-medium-thumb', 370, 220, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary'     => esc_html( __( 'Primary Menu', 'tm-lawyers' ) ),
			'primary3'    => esc_html( __( 'Header 03 Menu', 'tm-lawyers' ) ),
			'social-menu' => esc_html( __( 'Social Menu', 'tm-lawyers' ) )
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );

		/*
		 * Enable support for Post Formats.
		 * See http://codex.wordpress.org/Post_Formats
		 */
		add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link', 'gallery', 'audio' ) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'tm_lawyers_custom_background_args', array(
			'default-color' => '#333',
			'default-image' => '',
		) ) );

		// Support woocommerce
		add_theme_support( 'woocommerce' );
	}
endif; // tm_lawyers_setup
add_action( 'after_setup_theme', 'tm_lawyers_setup' );

/**
 * Define Constants
 * ================
 */
define( 'TM_LAWYERS_THEME_ROOT', esc_url( get_template_directory_uri() ) );
define( 'TM_LAWYERS_PARENT_THEME_NAME', wp_get_theme( get_template() )->get( 'Name' ) );
define( 'TM_LAWYERS_PARENT_THEME_VERSION', wp_get_theme( get_template() )->get( 'Version' ) );
define( 'TM_LAWYERS_PARENT_THEME_AUTHOR', wp_get_theme( get_template() )->get( 'Author' ) );
define( 'TM_LAWYERS_PRIMARY_COLOR', '#333333' );
define( 'TM_LAWYERS_SECONDARY_COLOR', '#C6A472' );
define( 'TM_LAWYERS_PRIMARY_FONT', 'EB Garamond' );
define( 'TM_LAWYERS_SECONDARY_FONT', 'Poppins' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 * ===========================================================================
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

/**
 * Register widget area.
 * ====================
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function tm_lawyers_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html( __( 'Sidebar', 'tm-lawyers' ) ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>'
	) );

	register_sidebar( array(
		'name'          => esc_html( __( 'Newsletter Form', 'tm-lawyers' ) ),
		'id'            => 'newsletter-form',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>'
	) );

	register_sidebar( array(
		'name'          => esc_html( __( 'Top Slider', 'tm-lawyers' ) ),
		'id'            => 'top-slider',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>'
	) );

	register_sidebar( array(
		'name'          => esc_html( __( 'Top Left', 'tm-lawyers' ) ),
		'id'            => 'top-left',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget header-right %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>'
	) );

	register_sidebar( array(
		'name'          => esc_html( __( 'Header 02 Info 1', 'tm-lawyers' ) ),
		'id'            => 'header02-info1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget header02-info1 %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>'
	) );

	register_sidebar( array(
		'name'          => esc_html( __( 'Header 02 Info 2', 'tm-lawyers' ) ),
		'id'            => 'header02-info2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget header02-info2 %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>'
	) );

	register_sidebar( array(
		'name'          => esc_html( __( 'Header 03 Info', 'tm-lawyers' ) ),
		'id'            => 'header03-info',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget header03-info %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>'
	) );

	if ( class_exists( 'WooCommerce' ) ) {
		register_sidebar( array(
			'name'          => esc_html( __( 'Sidebar for shop', 'tm-lawyers' ) ),
			'id'            => 'sidebar-shop',
			'description'   => '',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>'
		) );
	}
	register_sidebar( array(
		'name'          => esc_html( __( 'Footer 1 Widget Area', 'tm-lawyers' ) ),
		'id'            => 'footer',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html( __( 'Footer 2 Widget Area', 'tm-lawyers' ) ),
		'id'            => 'footer2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html( __( 'Footer 3 Widget Area', 'tm-lawyers' ) ),
		'id'            => 'footer3',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html( __( 'Footer 4 Widget Area', 'tm-lawyers' ) ),
		'id'            => 'footer4',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );
}

add_action( 'widgets_init', 'tm_lawyers_widgets_init' );

/**
 * Enqueue scripts and styles.
 * ==========================
 */
function tm_lawyers_scripts() {
	wp_enqueue_style( 'tm-lawyers-style', TM_LAWYERS_THEME_ROOT . '/style.css' );
	if ( Kirki::get_option( 'tm-lawyers', 'rtl' ) == 1 ) {
		wp_enqueue_style( 'tm-lawyers-main', TM_LAWYERS_THEME_ROOT . '/assets/css/output/main-rtl.css' );
	} else {
		wp_enqueue_style( 'tm-lawyers-main', TM_LAWYERS_THEME_ROOT . '/assets/css/output/main-ltr.css' );
	}
	wp_enqueue_style( 'tm-lawyers-icon', TM_LAWYERS_THEME_ROOT . '/assets/css/tm-lawyers-icon.css' );
	wp_enqueue_style( 'font-awesome', TM_LAWYERS_THEME_ROOT . '/assets/libs/font-awesome/css/font-awesome.min.css' );
	wp_enqueue_style( 'pe-icon-7-stroke', TM_LAWYERS_THEME_ROOT . '/assets/css/pe-icon-7-stroke.css' );
	if ( Kirki::get_option( 'tm-lawyers', 'nav_sticky_enable' ) == 1 ) {
		wp_enqueue_script( 'head-room-jquery', TM_LAWYERS_THEME_ROOT . '/assets/libs/headroom/jQuery.headroom.min.js', array( 'jquery' ), TM_LAWYERS_PARENT_THEME_VERSION, true );
		wp_enqueue_script( 'head-room', TM_LAWYERS_THEME_ROOT . '/assets/libs/headroom/headroom.min.js', array( 'jquery' ), TM_LAWYERS_PARENT_THEME_VERSION, true );
	}
	wp_enqueue_script( 'snap', TM_LAWYERS_THEME_ROOT . '/assets/libs/snap/snap.min.js', array(), TM_LAWYERS_PARENT_THEME_VERSION, true );
	wp_enqueue_script( 'owl-carousel', TM_LAWYERS_THEME_ROOT . '/assets/libs/owl-carousel/owl.carousel.min.js', array( 'jquery' ), TM_LAWYERS_PARENT_THEME_VERSION, true );
	wp_enqueue_script( 'counterup', TM_LAWYERS_THEME_ROOT . '/assets/libs/waypoint/jquery.counterup.min.js', array( 'jquery' ), TM_LAWYERS_PARENT_THEME_VERSION, true );
	wp_enqueue_script( 'fitvids', TM_LAWYERS_THEME_ROOT . '/assets/libs/jquery.fitvids.js', array( 'jquery' ), TM_LAWYERS_PARENT_THEME_VERSION, true );
	wp_enqueue_script( 'tm-lawyers-js-main', TM_LAWYERS_THEME_ROOT . '/assets/js/main.js', array( 'jquery' ), TM_LAWYERS_PARENT_THEME_VERSION, true );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}

add_action( 'wp_enqueue_scripts', 'tm_lawyers_scripts' );

/**
 * Setup custom css.
 * ================
 */
function tm_lawyers_custom_css() {
	$tm_lawyers_custom_css = Kirki::get_option( 'tm-lawyers', 'custom_css' );
	if ( Kirki::get_option( 'tm-lawyers', 'custom_css_enable' ) == 1 ) {
		wp_add_inline_style( 'tm-lawyers-main', html_entity_decode( $tm_lawyers_custom_css, ENT_QUOTES ) );
	}
}

add_action( 'wp_enqueue_scripts', 'tm_lawyers_custom_css' );

/**
 * Implement other setup.
 * ======================
 */
// Load core
require_once get_template_directory() . '/core/core.php';
require_once get_template_directory() . '/inc/customizer/customizer.php';
require_once get_template_directory() . '/inc/oneclick.php';

// Theme Hook Alliance
require_once get_template_directory() . '/inc/tha-theme-hooks.php';

// Load tmg
require_once get_template_directory() . '/inc/tgm-plugin-activation.php';
require_once get_template_directory() . '/inc/tgm-plugin-registration.php';

// Load metabox
require_once get_template_directory() . '/inc/meta-box.php';

// Load custom js
require_once get_template_directory() . '/inc/custom-js.php';

// Load custom header
require_once get_template_directory() . '/inc/custom-header.php';

// Custom template tags for this theme.
require_once get_template_directory() . '/inc/template-tags.php';

// Custom functions that act independently of the theme templates.
require_once get_template_directory() . '/inc/extras.php';

// Load Jetpack compatibility file.
require_once get_template_directory() . '/inc/jetpack.php';

// Support shortcode in widget
add_filter( 'widget_text', 'do_shortcode' );

// Remove admin notification of Projects
if ( class_exists( 'Projects_Admin' ) ) {
	global $projects;
	remove_action( 'admin_notices', array( $projects->admin, 'configuration_admin_notice' ) );
}

// TM Core Functions
if ( ! function_exists( 'infinity_base_encode' ) ) {
	function infinity_base_encode( $data ) {
		return $data;
	}
}

if ( ! function_exists( 'infinity_base_decode' ) ) {
	function infinity_base_decode( $data ) {
		return $data;
	}
}

if ( ! function_exists( 'is_tree' ) ) {
	function is_tree( $pid ) {
		global $post;
		if ( is_page() && ( $post->post_parent == $pid || is_page( $pid ) ) ) {
			return true;
		} else {
			return false;
		}
	}
}

// Extend VC
if ( class_exists( 'WPBakeryVisualComposerAbstract' ) ) {
	function tm_lawyers_requireVcExtend() {
		require get_template_directory() . '/inc/vc-extend.php';
	}

	add_action( 'init', 'tm_lawyers_requireVcExtend', 2 );
}

// 404 Page
add_action( 'tha_content_before', 'tm_lawyers_page404_before' );
function tm_lawyers_page404_before() {
	if ( is_404() ) {
		echo '<div class="error404-bg">';
	}
}

add_action( 'tha_content_after', 'tm_lawyers_page404_after' );
function tm_lawyers_page404_after() {
	if ( is_404() ) {
		echo '</div>';
	}
}

function tm_lawyers_search_filter( $query ) {
	if ( is_search() && ( ! isset( $query->query_vars['post_type'] ) ) ) {
		$query->set( 'post_type', array( 'post' ) );
	}
}

add_action( 'pre_get_posts', 'tm_lawyers_search_filter' );

function tm_lawyers_search_form( $form ) {
	$form = '<form method="get" class="search-form" action="' . home_url( '/' ) . '">
					<input type="search" class="search-field" placeholder="' . esc_attr__( 'Search...', 'tm-lawyers' ) . '" value="" name="s" title="' . esc_attr__( 'Search for:', 'tm-lawyers' ) . '">
				<input type="submit" class="search-submit" value="' . esc_attr__( 'Search', 'tm-lawyers' ) . '">
			</form>';

	return $form;
}

add_filter( 'get_search_form', 'tm_lawyers_search_form' );

add_action( 'init', 'tm_lawyers_remove_vc_tgm_update_notice' );
function tm_lawyers_remove_vc_tgm_update_notice() {
	global $vc_manager;
	if ( ! empty( $vc_manager ) ) {
		$updater = $vc_manager->updater();
		remove_filter( 'upgrader_pre_download', array( $updater, 'preUpgradeFilter' ), 10 );
	}
}